/* $Id: blowfish.c,v 1.4 1998/07/23 15:30:19 levitte Exp $ */

#include "Pilot.h"
#include "ssh.h"
#include "blowfish.h"
#include "util.h"

typedef struct {
    BF_KEY bf_key;
    unsigned char ivec[BF_BLOCK];
} Tblowfish_state;

void ssh_blowfish_encrypt(unsigned char *in, unsigned char *out, long len,
    void *encryptstate_)
{
    Tblowfish_state *encryptstate = encryptstate_;

    invert_byte_order(len, in);
    BF_cbc_encrypt(in, out, len, &encryptstate->bf_key,
		   encryptstate->ivec, BF_ENCRYPT);
    invert_byte_order(len, in);
}

void ssh_blowfish_decrypt(unsigned char *in, unsigned char *out, long len,
    void *decryptstate_)
{
    Tblowfish_state *decryptstate = decryptstate_;

    invert_byte_order(len, in);
    BF_cbc_encrypt(in, out, len, &decryptstate->bf_key,
		   decryptstate->ivec, BF_DECRYPT);
    invert_byte_order(len, in);
}

void ssh_blowfish_clean(ssh_state *state)
{
    MemPtrFree(state->encryptstate);
    MemPtrFree(state->decryptstate);
    state->encrypt = NULL;
    state->decrypt = NULL;
    state->cryptclean = NULL;
}

void *ssh_blowfish_encryptstate(ssh_state *state, Erf erf, void *erfp)
{
    Tblowfish_state *encryptstate = MemPtrNew(sizeof(Tblowfish_state));
    if (!encryptstate) {
	ssh_fatal("Out of mem");
	return NULL;
    }
    BF_set_key(&encryptstate->bf_key, 32, state->sesskey);
    MemSet(encryptstate->ivec, BF_BLOCK, 0);

    return encryptstate;
}

void *ssh_blowfish_decryptstate(ssh_state *state, Erf erf, void *erfp)
{
    Tblowfish_state *decryptstate = MemPtrNew(sizeof(Tblowfish_state));
    if (!decryptstate) {
	ssh_fatal("Out of mem");
	return NULL;
    }
    BF_set_key(&decryptstate->bf_key, 32, state->sesskey);
    MemSet(decryptstate->ivec, BF_BLOCK, 0);

    return decryptstate;
}

/* Emacs local variables

Local variables:
eval: (set-c-style "BSD")
end:

*/
