! $Id: descrip.mms,v 1.11 1998/07/23 19:13:38 levitte Exp $

! DESCRIP.MMS for FISH, a VMS SSH client.
!
!   Copyright (c) 1998, Christer Weinigel <wingel@ctrl-c.liu.se>
!   Copyright (c) 1998, Richard Levitte <richard@levitte.org>
!
!   See the file COPYRIGHT. for further information
!
!--------------------------------------------------------------
!
!	User macros.  Change at will.
!
! We need a few files from SSLeay.  YOU PROBABLY NEED TO CHANGE THIS!
SSLINCLUDEDIR = SSLINCLUDE:
SSLLIBDIR = SSLLIB:
SSLLIBRARYNAME = LIBCRYPTO.OLB

! The disabled PTRMISMATCH warning is because of the mixture of
! signed and unsigned char.
CC = cc /decc /debug /warning=(disable=(PTRMISMATCH,PREOPTW))
CFLAGS = /include=$(SSLINCLUDEDIR) 'internal_cflags'
LDFLAGS = 'internal_ldflags' /NOTRACEBACK

!--------------------------------------------------------------
!
!	Internal macro definitions.  Please do not change
!
LIBRARYMODULES = fish, ssh, packet, crc32, 3des, idea, rc4, blowfish, des, -
		 fish_internal, util
LIBRARIES = fishlib.olb($(LIBRARYMODULES)) 
SOURCEDIR = [-.SRC]

! All the source we distribute
DISTFILES = *.txt copyright.* *.com [.src]*.c [.src]*.h [.src]*.mms -
	    [.src]*.cld [.src]version.opt
! Some binaries we also distribute
ZIPDISTEXTRA = [.bin-*]*.*

! include version.opt, since that gives us information like version number.
.include version.opt

!--------------------------------------------------------------
!
!	On to the building part
!
.FIRST :
	@ CPU := VAX
	@ if f$getsyi("CPU") .ge. 128 then CPU := AXP
	@ if f$parse("[-.BIN-''CPU']") .eqs. "" then -
		create/dir [-.BIN-'CPU']
	@ SSLlibrary := $(SSLLIBDIR)LIBCRYPTO.OLB
	@ if f$search(SSLlibrary) .eqs. "" then -
		SSLlibrary := $(SSLLIBDIR)$(SSLLIBRARYNAME)
	@ if f$search(SSLlibrary) .eqs. "" then -
		SSLlibrary := [-.BIN-'CPU']LIBCRYPTO.OLB
	@ if f$search(SSLlibrary) .eqs. "" then -
		SSLlibrary :=
	@ if SSLlibrary .eqs. "" then -
		write sys$error "I can't find the SSLeay library in $(SSLLIBDIR)"
	@ if SSLlibrary .eqs. "" then exit
	@ tmp := f$search("$(SSLINCLUDEDIR)RAND.H")
	@ if tmp .eqs. "" then -
		write sys$error "I can't find the SSLeay include file RAND.H in $(SSLINCLUDEDIR)"
	@ if tmp .eqs. "" then exit
	internal_cflags :=
	internal_ldflags :=

all : fish.exe
	@ $

make_portable : vaxcrtl.opt
	! This is probably paranoid and overly redundant, but that's much
	! better than skiping it all...  Gotta do this for SSLeay as well.
	internal_cflags := /define=(__VMS_VER=60000000,__CRTL_VER=60000000,_VMS_V6_SOURCE=1,_DECC_V4_SOURCE=1)
	if CPU .eqs. "VAX" then internal_ldflags := ,vaxcrtl.opt/opt

fish.exe :  $(LIBRARIES) fish.opt
	copy fishlib.olb [-.BIN-'CPU']
	- link /exec=fish.exe fishlib/lib /include=(fish),fish.opt/opt,version.opt/opt $(LDFLAGS)
	copy fish.exe [-]

fish.opt : descrip.mms
	open/write fish_opt fish.opt
	write fish_opt SSLlibrary,"/LIB"
	write fish_opt "NETLIB_SHRXFR/SHARE"
	close fish_opt

vaxcrtl.opt : descrip.mms
	open/write vaxcrtl_opt vaxcrtl.opt
	write vaxcrtl_opt "SYS$SHARE:VAXCRTL/SHARE"
	close vaxcrtl_opt

almostclean :
	- purge/log
	- delete/log *.obj;*
	- delete/log *.exe;*,[-]*.exe;*

olbclean : 
	- delete/log *.olb;*

clean : almostclean
	- delete/log [-.BIN-'CPU']fishlib.olb;*

optclean :
	- delete/log fish.opt;*

distclean : clean optclean
	@ !

! Start with cleaning it all, then do a complete rebuild WITH PORTABILITY
! FLAGS ALL SET, then clean all you don't need, then build the distribution.
! If you think it's rough, well...
dist :  distclean make_portable all -
		almostclean optclean olbclean -
		versions zip.comment
	copy 'SSLlibrary' [-.BIN-'CPU']LIBCRYPTO.OLB
	purge [-.BIN-'CPU']
	set default [-]
	- delete fish'vmsver'.zip;*
	- define/user sys$input zip.comment
	- define/user sys$output zip.log
	- zip -"Vz" fish'vmsver'.zip $(DISTFILES) $(ZIPDISTEXTRA)

versions : version.opt FRC
	version = f$extract(1,10,$(IDENT))
	major = f$element(0,".",version)
	minor = f$element(0,"-",f$element(1,".",version))
	update = f$element(1,"-",version)
	vmsver = "0''major'''minor'"
	if major .gt. 9 then vmsver = "''major'''minor'"
	if update .nes. "-" then vmsver = "U''update'"+vmsver
	
zip.comment : version.opt descrip.mms
	- open/write foo [-]zip.comment
	- write foo ""
	- write foo "FISH ''version' -- an SSH client for VMS"
	- write foo ""
	- write foo "Runs on both OpenVMS/VAX and OpenVMS/AXP."
	- write foo ""
	- write foo "To get the executable, just do @LINK after you extracted"
	- write foo "the files."
	- write foo ""
	- close foo

FRC :
	@ ! This clause is to force other clauses to happen.

!--------------------------------------------------------------
!
!	Source dependencies
!
fish.obj : pilot.h ssh.h ui.h $(SSLINCLUDEDIR)rand.h erf.h
ssh.obj : pilot.h ssh.h $(SSLINCLUDEDIR)bn.h $(SSLINCLUDEDIR)rsa.h -
	  $(SSLINCLUDEDIR)rand.h $(SSLINCLUDEDIR)md5.h callback.h erf.h
packet.obj : pilot.h ssh.h crc32.h $(SSLINCLUDEDIR)rand.h callback.h erf.h
3des.obj : pilot.h ssh.h $(SSLINCLUDEDIR)des.h erf.h
idea.obj : pilot.h ssh.h $(SSLINCLUDEDIR)idea.h erf.h
rc4.obj : pilot.h ssh.h $(SSLINCLUDEDIR)rc4.h erf.h
blowfish.obj : pilot.h ssh.h $(SSLINCLUDEDIR)blowfish.h erf.h util.h
des.obj : pilot.h ssh.h $(SSLINCLUDEDIR)des.h erf.h
sock.obj : pilot.h sock.h ssh.h erf.h
ui.obj : pilot.h ui.h ssh.h erf.h
util.obj : util.h
fish_internal.obj : fish_internal.cld
